@@ -1,12 +1,18 @@
 #
 # -*- coding: utf-8 -*-
+# pylint: disable=missing-function-docstring, missing-module-docstring
+# pylint: disable=missing-class-docstring, redefined-outer-name
 
 import os
-
 import pytest
 
 import tomcatmanager as tm
-from tests.mock_server80 import start_mock_server80
+
+from tests.mock_server_10_0 import start_mock_server_10_0
+from tests.mock_server_9_0 import start_mock_server_9_0
+from tests.mock_server_8_5 import start_mock_server_8_5
+from tests.mock_server_8_0 import start_mock_server_8_0
+
 
 ###
 #
@@ -14,10 +20,13 @@ from tests.mock_server80 import start_mock_server80
 #
 ###
 class TomcatServer:
+    # pylint: disable=too-few-public-methods
     def __init__(self):
         self.url = None
         self.user = None
         self.password = None
+        self.cert = None
+        self.verify = True
         self.warfile = None
         self.contextfile = None
         self.connect_command = None
@@ -29,29 +38,51 @@ class TomcatServer:
 #
 ###
 def pytest_addoption(parser):
+    parser.addoption(
+        "--mocktomcat",
+        action="store",
+        default=tm.TomcatMajorMinor.highest_supported().value,
+        choices=list(map(lambda v: v.value, tm.TomcatMajorMinor.supported())),
+        help="test against a specific mock version of Tomcat",
+    )
     parser.addoption(
         "--url",
         action="store",
-        default=None,
-        help="url: url of tomcat manager to test against instead of mock",
+        help="url of tomcat manager to test against instead of mock server",
+    )
+    parser.addoption("--user", action="store", help="use to authenticate at url")
+    parser.addoption("--password", action="store", help="use to authenticate at url")
+    parser.addoption(
+        "--cert",
+        action="store",
+        help="certificate for client side authentication",
     )
     parser.addoption(
-        "--user", action="store", default=None, help="user: use to authenticate"
-    )
-    parser.addoption(
-        "--password", action="store", default=None, help="password: use to authenticate"
+        "--key",
+        action="store",
+        help="private key file for client side authentication",
     )
     parser.addoption(
         "--warfile",
         action="store",
-        default=None,
-        help="warfile: path to deployable war file on the tomcat server",
+        help="path to deployable war file on the tomcat server",
     )
     parser.addoption(
         "--contextfile",
         action="store",
-        default=None,
-        help="contextfile: path to context.xml file on the tomcat server",
+        help="path to context.xml file on the tomcat server",
+    )
+    parser.addoption(
+        "--cacert",
+        action="store",
+        help="path to certificate authority bundle or directory",
+    )
+    parser.addoption(
+        "--noverify",
+        # store_true makes the default False, aka default is to verify
+        # server certificates
+        action="store_true",
+        help="don't validate server SSL certificates",
     )
 
 
@@ -108,24 +139,48 @@ def tomcat_manager_server(request):
         tms.url = url
         tms.user = request.config.getoption("--user")
         tms.password = request.config.getoption("--password")
+        cert = request.config.getoption("--cert")
+        key = request.config.getoption("--key")
+        if cert and key:
+            cert = (cert, key)
+        tms.cert = cert
+        cacert = request.config.getoption("--cacert")
+        # the command line option is negative, so this flips it
+        verify = not request.config.getoption("--noverify")
+        if verify and cacert:
+            tms.verify = cacert
+        else:
+            tms.verify = verify
         tms.warfile = request.config.getoption("--warfile")
         tms.contextfile = request.config.getoption("--contextfile")
         tms.connect_command = "connect {} {} {}".format(tms.url, tms.user, tms.password)
         return tms
-    else:
-        # go start up a fake server
-        return start_mock_server80(tms)
+
+    # go start up a fake server
+    mockver = request.config.getoption("--mocktomcat")
+    if mockver == tm.TomcatMajorMinor.V10_0.value:
+        (mock_server, tms) = start_mock_server_10_0(tms)
+    if mockver == tm.TomcatMajorMinor.V9_0.value:
+        (mock_server, tms) = start_mock_server_9_0(tms)
+    if mockver == tm.TomcatMajorMinor.V8_5.value:
+        (mock_server, tms) = start_mock_server_8_5(tms)
+    if mockver == tm.TomcatMajorMinor.V8_0.value:
+        (mock_server, tms) = start_mock_server_8_0(tms)
+
+    yield tms
+    mock_server.shutdown()
 
 
 @pytest.fixture
 def tomcat(tomcat_manager_server):
-    tc = tm.TomcatManager()
-    tc.connect(
+    tmcat = tm.TomcatManager()
+    tmcat.connect(
         tomcat_manager_server.url,
         tomcat_manager_server.user,
         tomcat_manager_server.password,
+        cert=tomcat_manager_server.cert,
     )
-    return tc
+    return tmcat
 
 
 @pytest.fixture
